#ifndef MENU_H
#define MENU_H



#include "mbed.h"
#include "N5110.h"
#include "Gamepad.h"
#include "MazeEngine.h"
#include "Visuals.h"
#include "Maze.h"
#include "Ball.h"




/**
 @brief MainMenu Class runs the main menu which the program uses as a base.
 @author Chukwuebuka Nwibe
 @date May 2018
 */
class Menu
{
public:


    /**
      *  @details - constructor
      */
    Menu();


    /**
     *  @details - destructor
     */
    ~Menu();


    /** Initialise MainMenu
     * @details - Creates objects and default parameters for the game.
     */
    void init();


    /** Main MainMenu Function
     *  @details - Function runs the game and allows player to select between various game parameters.
     *  @param lcd - N5110 Library, used for drawing strings and printing bits of information(bitmaps).
     *  @param pad - Gamepad Library, used to read inputs from gamepad.
     *  @param visual - Visuals Library to provide on screen visuals.
     */
    void main(N5110 &lcd,
              Gamepad &pad,
              Visuals &visual);
              
              

    /** Intro Function
     *  @details - The main function which runs the game and allows player to select all different game parameters.
     *  @details - Called from main file when the game is loading.
     *  @param lcd - N5110 Library, used for drawing strings and printing bits of information(bitmaps)
     *  @param pad - Gamepad Library, used to read inputs from gamepad device.
     *  @param visual - Visuals Library to provide onscreen visuals.
     */
    void intro(N5110 &lcd, Gamepad &pad, Visuals &visual);
    
    
    

private:

    void playGame(N5110 &lcd,
                  Gamepad &pad,
                  Visuals &visual,
                  int mazeModel,
                  bool tone,
                  float FPS);


    void options(N5110 &lcd, Gamepad &pad, Visuals &visual, bool tone);

    void settings(N5110 &lcd, Gamepad &pad, Visuals &visual);

    void audiosettings(N5110 &lcd, Gamepad &pad, Visuals &visual);

    void levelOptions(N5110 &lcd, Gamepad &pad);


    void ballType(N5110 &lcd, Gamepad &pad, Visuals &visual);


    void lcdTheme(N5110 &lcd, Gamepad &pad);

    void gameBrightness(N5110 &lcd, Gamepad &pad, Visuals &visual);

    void visualMazeEnd(N5110 &lcd, Gamepad &pad, Visuals &visual);
    
    void visualGameOver(N5110 &lcd, Gamepad &pad, Visuals &visual);


    int mazeModelSelector(int level);

    MazeEngine _mazeEn;

    int _mazeModel;

    int _level;

    float _FPS;
    
    bool _control;
    
    bool _finish;
   
    bool _colour;

    bool _tone;
    
    Vector2D position1;
    
    Ball _ball;

};

#endif