 #ifndef MAZE_H
#define MAZE_H
 
#include "mbed.h"
#include "N5110.h"
#include "Visuals.h"




/**
 @brief Maze Class contains mazes to be drawn (as sprites or series of lines).
 @author Chukwuebuka Nwibe
 @date May 2018
 */ 
class Maze
{
    public:
    
    
    
    /**
     *  @details - constructor
     */
    Maze();
    
    
    /**
     *  @details - constructor
     */
    ~Maze();
    


    /** Initialises the maze
     *  @details - maze is initialised with specific maze model value
     *  @param mazeModel - int to select maze to be drawn.
     */
    void init(int mazeModel);
    
    
    
    /** Draw
     *  @details - Maze is drawn on LCD screen.
     *  @param lcd - N5110 Library used to draw lines, draw sprites and set pixels which make up maze.
     */
    void draw(N5110 &lcd, Visuals &visual);
    
private:
    
    
    //Adds lines and pixels to lcd buffer to draw up first maze model(model 0) which corresponds to easy level maze 1
    void mazeModelZero(N5110 &lcd, Visuals &visual);
    
    
    //Adds lines and pixels to lcd buffer to draw up second maze model(model 1) which corresponds to easy level maze 2
    void mazeModelOne(N5110 &lcd);
    
    
    //Adds lines and pixels to lcd buffer to draw up third maze model(model 2) which corresponds to easy level maze 3
    void mazeModelTwo(N5110 &lcd);

  
      
    int _mazeModel;
    
};
#endif 