#include "MazeEngine.h"
 
MazeEngine::MazeEngine()
{
 
}
 
MazeEngine::~MazeEngine()
{
 
}

void MazeEngine::init(int mazeModel, int x, int y, int radius, bool colour, bool control) //define game parameters
{
    
    //define parameters for ball
    _radius = radius;
    _x = x;
    _y = y;
    _colour = colour;
    _control = control;
    
     //define parameters for maze 
    _mazeModel = mazeModel;
    
    // initialise with given parameters
    _ball.init(_x, _y, _radius, _colour);
    _maze.init(_mazeModel);
    
    _ball.init(8, 5, _radius, _colour);
    
}

//reads joystick input ans sets them to control ball movememnt
void MazeEngine::readInput(Gamepad &pad)
{
  _control = true;
  getJoystickInput(pad);

}


void MazeEngine::update(N5110 &lcd)
{
    if (checkFinish()){

        return;
        
    }
    
    //update ball position based on input (using joystick)
    _ball.update(position);
    


    // reverts the changes if the proposed new ball position is a wall
   checkCollision(lcd);
}
 
 
 
 //Acquires maze array for wall collision checks
void MazeEngine::getMazeArray(N5110 &lcd)
{
    
    for (int i = 0; i < 84; i++){
        for (int j = 0; j < 48; j++){
            
            int pixel = lcd.getPixel(i, j);
            
            if (pixel == 1){
                
                _mazeArray[i][j] = 1;
            }
            else {
                
                _mazeArray[i][j] = 0;
            }
        }
        
    }
    
}




void MazeEngine::checkCollision(N5110 &lcd)
{
    
    //get position of ball for wall collision check
    Vector2D _position = _ball.getPosition();
    Vector2D _velocity = _ball.getSpeed();
    printf("position = (%f, %f) \n", _position.x, _position.y);
    
    
    int leftSide = int(_position.x - _radius);  //outermost left side pixel x centre minus radius
    int rightSide = int(_position.x + _radius); //outermost right side pixel
    int topSide = int(_position.y - _radius); //outermost top pixel
    int bottomSide = int (_position.y + _radius); //outermost bottom pixel
    
    
    // check ball position
    // if distance between outermost pixel and centre != original distance
    // there must be a pixel in adjacent position
    
    
    if (rightSide + _mazeArray[rightSide + 1][int(_position.y)] != rightSide){
        
        _velocity.x = 0;//set velocity = 0
        _position.x -= 1; // ball set to no further right movement
    }
    
    
    if (topSide + _mazeArray[int(_position.x)][topSide - 1] != topSide){
        
        _velocity.y = 0;//set velocity = 0
        _position.y += 1; // ball set to no further top movement
    }
    
    if (bottomSide + _mazeArray[int(_position.x)][bottomSide + 1] != bottomSide){
        
        _velocity.y = 0; //set velocity = 0
        _position.y -= 1;// ball set to no further bottom movement
    }
    
    if (leftSide + _mazeArray[leftSide - 1][int(_position.y)] != leftSide){
        
        _velocity.x = 0; // set velocity = 0
         _position.x += 1; // ball set to no further left movement
        printf("left side hit \n");
    }
    
    _ball.setPosition(_position);
    _ball.setSpeed(_velocity);
    
}

 
 
//gets joystick input as mapped coordinate(x,y)
void MazeEngine::getJoystickInput(Gamepad &pad)
{
       position = pad.get_mapped_coord();
    
}



//check if maze has been completed
//boolean variable where true = completed and false = not completed
//only true if x (x coordinate of ball centre) > 83 (maximum x for lcd buffer)
bool MazeEngine::checkFinish()
{
    Vector2D position = _ball.getPosition();


        if (position.x > 86){
            _finish = true;
            return _finish;
        }

    
    return _finish;
}

 
//draw needed maze and ball for particular level and ball type
void MazeEngine::draw(N5110 &lcd, Visuals &visual)
{
    _ball.draw(lcd);
    _maze.draw(lcd,visual);
}