#ifndef VISUALS_H
#define VISUALS_H

#include "mbed.h"
#include "N5110.h"
#include "Gamepad.h"



/**
 @brief Visuals Class made up of all onscreen visuals within game.
 @author Chukwuebuka Nwibe
 @date May 2018
 */
class Visuals
{
    
    
public:
    
    /**
     *  @details - constructor
     */
    Visuals();
    
    
    /**
     *  @details - destructor
     */
    ~Visuals(); 
    
    
    /** Intro
     *  @details - Introduction page during the loading of the game. Checks if start is pressed to initialise game menu.
     *  @param - lcd - N5110 Libarary used to print strings and draw the ball
     *  @param - pad - Gamepad Library used to initialise game menu (when start is pressed).
     */
    void intro(N5110 &lcd, Gamepad &pad);
    
    
    /** Audio Switch
     *  @details - Displays an onscreen switch made up of one outer rectangle and two inner ones. Only one of the inner rectangles is drawn at every instant. This is decided by the boolean value of 'tone'.
     *  @param - lcd - N5110 Libarary used to print rectangles on the screen.
     *  @param - tone - Boolean variable to manage the appearance of the switch on the screen.
     */
    void audioSwitch(N5110 &lcd, Gamepad &pad, bool tone);
    
    
    /** Maze Explored
     *  @details - Displays an onscreen animation when user has completed maze.
     *  @param - lcd - N5110 Libarary used to print rectangles on the screen.
     */
    void mazeExplored(N5110 &lcd, Gamepad &pad);
    
    void mazeOver(N5110 &lcd, Gamepad &pad);
    
    
    
private:

};

#endif 